package no.hig.okolloen.graphics;

import java.text.SimpleDateFormat;
import java.util.Date;
import no.hig.okolloen.graphics.digit.*;

/**
 * DateStrip is a wrapper class for DigitStrip and is used to display dates.
 * <p>
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class DateStrip extends DigitStrip {
    private SimpleDateFormat sdf;

    /**
     *	Default Constructor for the DateStrip.
     *  @param images Object of the ImageColl class, holding the images for the style that will be used in this DateStrip.
     */
    public DateStrip (ImageColl images) {
        super (images, ((new SimpleDateFormat ("yyyy.MM.dd")).format (new java.sql.Date (1999, 12, 12)).length()));
        sdf = new SimpleDateFormat ("yyyy.MM.dd");
    }

    /**
     *	Constructor for the DateStrip.
     *  @param images Object of the ImageColl class, holding the images for the style that will be used in this DateStrip.
     *  @param format Format string for date formating, see java.text.SimpleDateFormat for syntax.
     */
    public DateStrip (ImageColl images, String format) {
        super (images, ((new SimpleDateFormat (format)).format (new java.sql.Date (1999, 12, 12)).length()));
        sdf = new SimpleDateFormat (format);
    }

    /**
     *	Updates this DateStrip to show the current date.
     */
    public void update () {
        setValue (sdf.format (new Date ()));
    }

    /**
     *	Updates this DateStrip to show the given date.
     *  @param date, Date object holding the date to display.
     */
    public void update (Date date) {
        setValue (sdf.format (date));
    }
}