package no.hig.okolloen.graphics;

import java.awt.*;
import java.awt.event.*;

/**
 * Knob is the basis if other dialknob classes and provides the display
 * of a basic knob and interaction with the mouse.
 * You can set various options for the Knob component like :
 * <ul>
 * <li>The max and min angle used as the active area
 * <li>The max and min values returned by this component
 * <li>The color of the top of the knob
 * </ul>
 * <p>
 * The knob component is freely scalable in both directions.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class MarkedKnob extends Knob {
    int marks = 7;
    int markedKnobxOffset = 10;
    int markedKnobyOffset = 10;

    public MarkedKnob () {
        super ();
        knobxoffset += 10;
        knobyoffset += 10;
    }

    /**
     *  Updates this component.
     *  @param g the graphics context.
     *  @see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *  Sets the number of marks shown for this knob
     *  @param marks the number of marks to show (legal values 2, 3, 7)
     */
    public void setMarks (int marks) {
        this.marks = marks;
        repaint ();
    }

    /**
     *  Gets the number of marks shown for this knob
     *  @return int the number of marks shown on this knob
     */
    public int getMarks () {
        return marks;
    }

    /**
     *	Paints this component.
     *	@param g the graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint(Graphics g) {
        super.paint (g);
        int height = getSize().height;
        int width = getSize().width;

        Rectangle clip = g.getClipBounds();

        bg.setColor (Color.black);
        bg.drawArc (markedKnobxOffset-1, markedKnobyOffset-1, size+6, size+6, minAngle, maxAngle-minAngle);
        if ((marks==3)||(marks==7)) {
            bg.drawLine (markedKnobxOffset-1+(size+6)/2, markedKnobyOffset-5, markedKnobxOffset-1+(size+6)/2, markedKnobyOffset-1);
        }
        double innerRadius = ((double)size+4)/2;
        double outerRadius = ((double)size+12)/2;
        double offset = innerRadius+markedKnobxOffset;
        double piQuarterSin = java.lang.Math.sin(java.lang.Math.PI/4);
        if (marks==7) {
            bg.drawLine ((int)(offset-outerRadius*piQuarterSin), (int)(offset-outerRadius*piQuarterSin), (int)(offset-innerRadius*piQuarterSin), (int)(offset-innerRadius*piQuarterSin)); 
            bg.drawLine ((int)(offset+outerRadius*piQuarterSin), (int)(offset-outerRadius*piQuarterSin), (int)(offset+innerRadius*piQuarterSin), (int)(offset-innerRadius*piQuarterSin)); 
        }
        if ((marks==2)||(marks==7)||(marks==3)) {
            bg.drawLine ((int)(offset-outerRadius*piQuarterSin), (int)(offset+outerRadius*piQuarterSin), (int)(offset-innerRadius*piQuarterSin), (int)(offset+innerRadius*piQuarterSin)); 
            bg.drawLine ((int)(offset+outerRadius*piQuarterSin), (int)(offset+outerRadius*piQuarterSin), (int)(offset+innerRadius*piQuarterSin), (int)(offset+innerRadius*piQuarterSin)); 
        }
        if (marks==7) {
            bg.drawLine (markedKnobxOffset-5, markedKnobyOffset-1+(size+6)/2, markedKnobxOffset-1, markedKnobyOffset-1+(size+6)/2);
            bg.drawLine (markedKnobxOffset+5+size, markedKnobyOffset-1+(size+6)/2, markedKnobxOffset+9+size, markedKnobyOffset-1+(size+6)/2);
        }

        if(clip != null)
            g.setClip(clip);

        g.drawImage(buffer, 0, 0, this);
    }
}