package no.hig.okolloen.graphics;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.sql.Time;
import no.hig.okolloen.graphics.digit.*;

/**
 * TimeStrip is a wrapper class for DigitStrip and is used to display time values.
 * <p>
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class TimeStrip extends DigitStrip {
    private SimpleDateFormat sdf;

    /**
     *	Default Constructor for the TimeStrip.
     *  @param images Object of the ImageColl class, holding the images for the style that will be used in this TimeStrip.
     */
    public TimeStrip (ImageColl images) {
        super (images, ((new SimpleDateFormat ("h:mma")).format (new Time (13, 13, 13)).length()));
        sdf = new SimpleDateFormat ("h:mma");
    }

    /**
     *	Constructor for the TimeStrip.
     *  @param images Object of the ImageColl class, holding the images for the style that will be used in this TimeStrip.
     *  @param format Format string for time formating, see java.text.SimpleDateFormat for syntax.
     */
    public TimeStrip (ImageColl images, String format) {
        super (images, ((new SimpleDateFormat (format)).format (new Time (13, 13, 13)).length()));
        sdf = new SimpleDateFormat (format);
    }

    /**
     *	Updates this TimeStrip to show the current time.
     */
    public void update () {
        setValue (sdf.format (new Date ()));
    }

    /**
     *	Updates this TimeStrip to show the given time.
     *  @param date Date object holding the time to display.
     */
    public void update (Date date) {
        setValue (sdf.format (date));
    }

}