package no.hig.okolloen.graphics.chart;

import java.awt.*;

/**
 * The Chart class is the basis for the BarChart and LineChart classes.
 * This class is responsible for laying out the basic structure of a Chart display.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class Chart extends Panel {
    int top;
    int bottom;
    int left;
    int right;
    int labelWidth = 0;
    int fontHeight;
    FontMetrics fm;
    int padding = 4;
    transient Graphics bg;
    transient Image buffer;
    transient int bufferWidth; 
    transient int bufferHeight;
    String labels[];
    Color bgColor;
    Color fgColor;

    /**
     *	Constructor for the Chart class.
     */
    public Chart () {
        bgColor = Color.white;
        fgColor = Color.black;
    }

    /**
     *	Sets the background color.
     *  @param c the color to use for the background.
     */
    public void setBGColor (Color c) {
        bgColor = c;
    }

    /**
     *	Sets the color used to draw the grid lines and label text.
     *  @param c the color to use for the grid lines and label text.
     */
    public void setFGColor (Color c) {
        fgColor = c;
    }

    /**
     *	Updates this component.
     *  @param g the Graphics context.
     *	@see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *	Paints this component.
     *	@param g the Graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint(Graphics g) {
        fm = g.getFontMetrics ();
        int height = getSize().height;
        int width = getSize().width;

        if(buffer == null || width != bufferWidth || height != bufferHeight) {
            buffer = createImage(width, height);
            bg = buffer.getGraphics();
            bufferWidth = width;
            bufferHeight = height;
        }

        top = padding+fm.getHeight();
        bottom = height-padding;
        right = width-padding;
        labelWidth = 0;
        if (labels!=null)
             for (int i=0; i<5; i++)
                  if ((labels[i]!=null)&&(fm.stringWidth(labels[i])>labelWidth))
                      labelWidth = fm.stringWidth(labels[i]);
        labelWidth += 2;
        left = labelWidth+padding;
        fontHeight = fm.getHeight();

        bg.setColor (bgColor);
        bg.fillRect (0, 0, width, height);
        bg.setColor (fgColor);

        if (labels!=null) {
            if (labels[0]!=null)
                bg.drawString (labels[0], padding-2+labelWidth-fm.stringWidth(labels[0]), top+fontHeight/2);
            if (labels[1]!=null)
                bg.drawString (labels[1], padding-2+labelWidth-fm.stringWidth(labels[1]), top+(bottom-top)/4+fontHeight*3/8);
            if (labels[2]!=null)
                bg.drawString (labels[2], padding-2+labelWidth-fm.stringWidth(labels[2]), top+(bottom-top)/2+fontHeight/4);
            if (labels[3]!=null)
                bg.drawString (labels[3], padding-2+labelWidth-fm.stringWidth(labels[3]), top+(bottom-top)*3/4+fontHeight/8);
            if (labels[4]!=null)
                bg.drawString (labels[4], padding-2+labelWidth-fm.stringWidth(labels[4]), bottom);
        }
        bg.drawLine (left-1, top, left-1, bottom);
        bg.drawLine (left-1, bottom, right, bottom);

        Rectangle clip = g.getClipBounds();
        if(clip != null)
            g.setClip(clip);

        g.drawImage(buffer, 0, 0, this);
    }
}    