package no.hig.okolloen.graphics.chart;

import java.awt.Color;

/**
 * Just a collection of data that is used to represent a datapoint in a Chart.
 * Contains the value, title and color representing this datapoint.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class ChartItem {
    String title;
    double value;
    Color color;

    /**
     *	Constructor for the ChartItem class.
     *  @param value the value of this datapoint.
     */
    public ChartItem (double value) {
        this (null, value, Color.black);
    }

    /**
     *	Constructor for the ChartItem class.
     *  @param value the value of this datapoint.
     *  @param color the color used to draw this datapoint
     */
    public ChartItem (double value, Color color) {
        this (null, value, color);
    }

    /**
     *	Constructor for the ChartItem class.
     *  @param title the title or legend value of this datapoint
     *  @param value the value of this datapoint.
     *  @param color the color used to draw this datapoint
     */
    public ChartItem (String title, double value, Color color) {
        this.title = title;
        this.value = value;
        this.color = color;
    }

    /**
     *	Retrieves the title of this datapoint.
     *  @return String object with the title of the datapoint.
     */
    public String getTitle () {
        return title;
    }

    /**
     *	Retrieves the value of this datapoint.
     *  @return double with the value of this datapoint.
     */
    public double getValue () {
        return value;
    }

    /**
     *	Retrieves the color of this datapoint.
     *  @return Color object with the color of the datapoint.
     */
    public Color getColor () {
        return color;
    }
    /**
     *	sets the title of this datapoint.
     *  @param title String object with the title of the datapoint.
     */
    public void setTitle (String title) {
        this.title = title;
    }

    /**
     *	sets the value of this datapoint.
     *  @param value the value of this datapoint.
     */
    public void setValue (double value) {
        this.value = value;
    }

    /**
     *	sets the color of this datapoint.
     *  @param color object with the color of the datapoint.
     */
    public void setColor (Color color) {
        this.color = color;
    }
}