package no.hig.okolloen.graphics.digit;

import java.awt.*;

/**
 * DigitCellPane is the basis for the DigitStrip class.
 * This object is used to hold a single digit and can be used as 
 * a standalone component as well. 
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class DigitCellPane extends Panel {
    private ImageColl images;
    private String currentState;

    /**
     *	Constructor for the DigitCellPane class.
     *  @param images, an object of the ImageColl class that holds the images for the style that will be used for this digit.
     */
    public DigitCellPane (ImageColl images) {
        super ();
        this.images = images;
        currentState = "0";
    }

    /**
     *	Updates this component.
     *  @param g the graphics context.
     *	@see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *	Paints this component.
     *	@param g the graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint(Graphics g) {

        Rectangle clip = g.getClipBounds();
        if(clip != null)
            g.setClip(clip);
        if (currentState.equals("-"))
            g.drawImage(images.getMinus(), 0, 0, this);
        else if (currentState.equals("."))
            g.drawImage(images.getDot(), 0, 0, this);
        else if (currentState.equals(":"))
            g.drawImage(images.getColon(), 0, 0, this);
        else if (currentState.equals("a"))
            g.drawImage(images.getAM(), 0, 0, this);
        else if (currentState.equals("p"))
            g.drawImage(images.getPM(), 0, 0, this);
        else if (currentState.equals("0"))
            g.drawImage(images.getZero(), 0, 0, this);
        else if (currentState.equals("1"))
            g.drawImage(images.getOne(), 0, 0, this);
        else if (currentState.equals("2"))
            g.drawImage(images.getTwo(), 0, 0, this);
        else if (currentState.equals("3"))
            g.drawImage(images.getThree(), 0, 0, this);
        else if (currentState.equals("4"))
            g.drawImage(images.getFour(), 0, 0, this);
        else if (currentState.equals("5"))
            g.drawImage(images.getFive(), 0, 0, this);
        else if (currentState.equals("6"))
            g.drawImage(images.getSix(), 0, 0, this);
        else if (currentState.equals("7"))
            g.drawImage(images.getSeven(), 0, 0, this);
        else if (currentState.equals("8"))
            g.drawImage(images.getEight(), 0, 0, this);
        else if (currentState.equals("9"))
            g.drawImage(images.getNine(), 0, 0, this);
        g.dispose();
    }

    /**
     *	Returns the preferred size of this component.
     *	@return A Dimension object representing the preferred size of this component.
     *	@see java.awt.Component#getPreferredSize
     */
    public Dimension getPreferredSize() {
        return new Dimension(images.getWidth(this), images.getHeight(this));
    }

    /**
     *	Sets the state for this cell.
     *  @param state the new state for this cell. (values "0".."9", ":", ".", "-", "a", "p").
     */
    public void setState (String state) {
        if (state.equals(currentState))
            return;
        currentState = state.toLowerCase();
        repaint();
    }
}