package no.hig.okolloen.graphics.digit;

import java.awt.Image;
import java.awt.image.*;
import javax.swing.ImageIcon;

/**
 * ImageColl is the basis for all the DigitStrip classes (DigitStrip, DateStrip and TimeStrip).
 * This class is used to hold the different images used by the DigitStrip class. 
 * The images will be read from a subdirectory. The structure is : 
 * <ul>
 * <li>directory where this class resides
 * <ul>
 * <li>digits
 * <ul>
 * <li>style a subdir
 * <li>style b subdir
 * <li>style c subdir
 * </ul></ul></ul>
 * where "style a subdir" etc is the directories for the different styles.
 * <p>
 * Each of these directories must include the following files : 
 * <ul>
 * <li>Am.gif - Image for the am indicator
 * <li>Pm.gif - Image for the pm indicator
 * <li>Colon.gif - Image for the colon (":") sign
 * <li>Dot.gif - Image for the dot (".") sign
 * <li>Dash.gif - Image for the minus ("-") sign
 * <li>Zero.gif - Image for the digit 0
 * <li>One.gif - Image for the digit 1
 * <li>Two.gif - Image for the digit 2
 * <li>Three.gif - Image for the digit 3
 * <li>Four.gif - Image for the digit 4
 * <li>Five.gif - Image for the digit 5
 * <li>Six.gif - Image for the digit 6
 * <li>Seven.gif - Image for the digit 7
 * <li>Eight.gif - Image for the digit 8
 * <li>Nine.gif - Image for the digit 9
 * </ul>
 * <p>
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class ImageColl {
    private Image dash = null;
    private Image dot = null;
    private Image colon = null;
    private Image minus = null;
    private Image am = null;
    private Image pm = null;
    private Image zero = null;
    private Image one = null;
    private Image two = null;
    private Image three = null;
    private Image four = null;
    private Image five = null;
    private Image six = null;
    private Image seven = null;
    private Image eight = null;
    private Image nine = null;

    /**
     *	Constructor for the ImageColl class.
     *  Reads images from a catalog to build a new image collection that holds all images for a particular style.
     *  @param collName Name of the catalog below digits that holds the images for this collection.
     */
    public ImageColl (String collName) {
        minus = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Dash.gif" ))).getImage();
        dot = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Dot.gif" ))).getImage();
        colon = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Colon.gif" ))).getImage();
        am = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Am.gif" ))).getImage();
        pm = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Pm.gif" ))).getImage();
        zero = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Zero.gif" ))).getImage();
        one = (new ImageIcon(getClass().getResource( "digits/"+collName+"/One.gif" ))).getImage();
        two = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Two.gif" ))).getImage();
        three = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Three.gif" ))).getImage();
        four = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Four.gif" ))).getImage();
        five = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Five.gif" ))).getImage();
        six = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Six.gif" ))).getImage();
        seven = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Seven.gif" ))).getImage();
        eight = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Eight.gif" ))).getImage();
        nine = (new ImageIcon(getClass().getResource( "digits/"+collName+"/Nine.gif" ))).getImage();
    }

    /**
     *	Method for getting the image object representing a minus ("-") sign.
     *  @return Image object holding the image for this sign.
     */
    public Image getMinus () {
        return minus;
    }

    /**
     *	Method for getting the image object representing a dot (".") sign.
     *  @return Image object holding the image for this sign.
     */
    public Image getDot () {
        return dot;
    }

    /**
     *	Method for getting the image object representing a colon (":") sign.
     *  @return Image object holding the image for this sign.
     */
    public Image getColon () {
        return colon;
    }

    /**
     *	Method for getting the image object representing a am ("AM") indicator.
     *  @return Image object holding the image for this indicator.
     */
    public Image getAM () {
        return am;
    }

    /**
     *	Method for getting the image object representing a pm ("PM") indicator.
     *  @return Image object holding the image for this indicator.
     */
    public Image getPM () {
        return pm;
    }

    /**
     *	Method for getting the image object representing the digit 0.
     *  @return Image object holding the image for this digit.
     */
    public Image getZero () {
        return zero;
    }

    /**
     *	Method for getting the image object representing the digit 1.
     *  @return Image object holding the image for this digit.
     */
    public Image getOne () {
        return one;
    }

    /**
     *	Method for getting the image object representing the digit 2.
     *  @return Image object holding the image for this digit.
     */
    public Image getTwo () {
        return two;
    }

    /**
     *	Method for getting the image object representing the digit 3.
     *  @return Image object holding the image for this digit.
     */
    public Image getThree () {
        return three;
    }

    /**
     *	Method for getting the image object representing the digit 4.
     *  @return Image object holding the image for this digit.
     */
    public Image getFour () {
        return four;
    }

    /**
     *	Method for getting the image object representing the digit 5.
     *  @return Image object holding the image for this digit.
     */
    public Image getFive () {
        return five;
    }

    /**
     *	Method for getting the image object representing the digit 6.
     *  @return Image object holding the image for this digit.
     */
    public Image getSix () {
        return six;
    }

    /**
     *	Method for getting the image object representing the digit 7.
     *  @return Image object holding the image for this digit.
     */
    public Image getSeven () {
        return seven;
    }

    /**
     *	Method for getting the image object representing the digit 8.
     *  @return Image object holding the image for this digit.
     */
    public Image getEight () {
        return eight;
    }

    /**
     *	Method for getting the image object representing the digit 9.
     *  @return Image object holding the image for this digit.
     */
    public Image getNine () {
        return nine;
    }

    /**
     *	Returns the height of a digit in this style.
     *  @param observer ImageObserver object that will be user to show this image.
     *  @return int value representing current height.
     */
    public int getHeight (ImageObserver observer) {
        if (minus!=null)
            return minus.getHeight (observer);
        else
            return 30;
    }

    /**
     *	Returns the width of a digit in this style.
     *  @param observer ImageObserver object that will be user to show this image.
     *  @return int value representing current width.
     */
    public int getWidth (ImageObserver observer) {
        if (minus!=null)
            return minus.getWidth (observer);
        else
            return 30;
    }
}