package no.hig.okolloen.graphics.frame;

import javax.swing.ImageIcon;
import java.awt.*;

/**
 * SteelFrame is a class used to make a frame around other components
 * that resemples a steel frame complete with screws and everything.
 * SteelFrame can be used to make a steel frame around any Java component. 
 * <p>
 * Usage : <br>
 * Panel p = new Panel();<br>
 * Panel p1 = new SteelFrame (p);<br>
 * <p>
 * p1 will now be a panel with a steel frame and can be added to your layout
 * as any other component.
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class SteelFrame extends Panel {
    private Image ul = null;
    private Image ur = null;
    private Image ll = null;
    private Image lr = null;
    private LeftPanel leftPane = null;
    private RightPanel rightPane = null;
    private TopPanel topPane = null;
    private BottomPanel bottomPane = null;
    private Component c = null;
    private String label = null;

    /**
     *	Constructor for the SteelFrame class.
     *  @param c The component that you want to embed in a steel frame.
     */
    public SteelFrame (Component c) {
        super ();
        ul = (new ImageIcon(getClass().getResource( "screw1.gif" ))).getImage();
        ur = (new ImageIcon(getClass().getResource( "screw2.gif" ))).getImage();
        ll = (new ImageIcon(getClass().getResource( "screw3.gif" ))).getImage();
        lr = (new ImageIcon(getClass().getResource( "screw4.gif" ))).getImage();
        leftPane = new LeftPanel (c);
        rightPane = new RightPanel (c);
        topPane = new TopPanel (ul, ur, c);
        bottomPane = new BottomPanel (ll, lr, c);
        setLayout (new BorderLayout());
        add (leftPane, BorderLayout.WEST);
        add (rightPane, BorderLayout.EAST);
        add (topPane, BorderLayout.NORTH);
        add (bottomPane, BorderLayout.SOUTH);
        add (c, BorderLayout.CENTER);
        this.c = c;
    }

    /**
     *	Constructor for the SteelFrame class.
     *  @param c The component that you want to embed in a steel frame.
     *  @param label Caption displayed in the top of the steel frame.
     */
    public SteelFrame (Component c, String label) {
        super ();
        ul = (new ImageIcon(getClass().getResource( "screw1.gif" ))).getImage();
        ur = (new ImageIcon(getClass().getResource( "screw2.gif" ))).getImage();
        ll = (new ImageIcon(getClass().getResource( "screw3.gif" ))).getImage();
        lr = (new ImageIcon(getClass().getResource( "screw4.gif" ))).getImage();
        leftPane = new LeftPanel (c);
        rightPane = new RightPanel (c);
        topPane = new TopPanel (ul, ur, c);
        bottomPane = new BottomPanel (ll, lr, c);
        setLayout (new BorderLayout());
        add (leftPane, BorderLayout.WEST);
        add (rightPane, BorderLayout.EAST);
        add (topPane, BorderLayout.NORTH);
        add (bottomPane, BorderLayout.SOUTH);
        add (c, BorderLayout.CENTER);
        this.c = c;
        this.label = label;
    }


    private class LeftPanel extends Panel {
        private transient Graphics bg;
        private transient Image buffer;
        private transient int bufferWidth; 
        private transient int bufferHeight;
        private Component c;

        public LeftPanel (Component c) {
            super ();
            this.c = c;
        }        

        /**
         *  Updates this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#update
         */
        public void update(Graphics g) {
            paint(g);
        }

        /**
         *  Paints this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#paint
         */	
        public void paint(Graphics g) {
            int height = getSize().height;
            int width = getSize().width;
            if(buffer == null || width != bufferWidth || height != bufferHeight) {
                buffer = createImage(width, height);
                bg = buffer.getGraphics();
                bufferWidth = width;
                bufferHeight = height;
            }
            bg.setColor (new Color (192, 192, 192));
            bg.fillRect (0, 0, width, height);
            bg.setColor (new Color(255, 255, 255));
            bg.drawLine (0, 0, 0, height);
            bg.setColor (new Color (128, 128, 128));
            bg.drawLine (width-1, 0, width-1, height);
            Rectangle clip = g.getClipBounds();
            if(clip != null)
                g.setClip(clip);
            g.drawImage(buffer, 0, 0, this);
            g.dispose();
        }

        /**
         *  Returns the preferred size of this component.
         *  @return A Dimension object representing the preferred size of this component.
         *  @see java.awt.Component#getPreferredSize
         */
        public Dimension getPreferredSize() {
            Dimension d = c.getPreferredSize();
            return new Dimension(20, (int)d.getHeight());
        }
    }

    private class RightPanel extends Panel {
        private transient Graphics bg;
        private transient Image buffer;
        private transient int bufferWidth; 
        private transient int bufferHeight;
        private Component c;

        public RightPanel (Component c) {
            super ();
            this.c = c;
        }        

        /**
         *  Updates this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#update
         */
        public void update(Graphics g) {
            paint(g);
        }

        /**
         *  Paints this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#paint
         */	
        public void paint(Graphics g) {
            int height = getSize().height;
            int width = getSize().width;
            if(buffer == null || width != bufferWidth || height != bufferHeight) {
                buffer = createImage(width, height);
                bg = buffer.getGraphics();
                bufferWidth = width;
                bufferHeight = height;
            }
            bg.setColor (new Color (192, 192, 192));
            bg.fillRect (0, 0, width, height);
            bg.setColor (new Color (128, 128, 128));
            bg.drawLine (width-1, 0, width-1, height);
            bg.setColor (new Color (255, 255, 255));
            bg.drawLine (0, 0, 0, height);
            Rectangle clip = g.getClipBounds();
            if(clip != null)
                g.setClip(clip);
            g.drawImage(buffer, 0, 0, this);
            g.dispose();
        }

        /**
         *  Returns the preferred size of this component.
         *  @return A Dimension object representing the preferred size of this component.
         *  @see java.awt.Component#getPreferredSize
         */
        public Dimension getPreferredSize() {
            Dimension d = c.getPreferredSize();
            return new Dimension(20, (int)d.getHeight());
        }
    }

    private class TopPanel extends Panel {
        private transient Graphics bg;
        private transient Image buffer;
        private transient int bufferWidth; 
        private transient int bufferHeight;
        private Component c;
        private Image ul;
        private Image ur;

        public TopPanel (Image ul, Image ur, Component c) {
            super ();
            this.ul = ul;
            this.ur = ur;
            this.c = c;
        }        

        /**
         *  Updates this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#update
         */
        public void update(Graphics g) {
            paint(g);
        }

        /**
         *  Paints this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#paint
         */	
        public void paint(Graphics g) {
            int height = getSize().height;
            int width = getSize().width;
            if(buffer == null || width != bufferWidth || height != bufferHeight) {
                buffer = createImage(width, height);
                bg = buffer.getGraphics();
                bufferWidth = width;
                bufferHeight = height;
            }
            bg.setColor (new Color (192, 192, 192));
            bg.fillRect (0, 0, width, height);
            bg.setColor (new Color (128, 128, 128));
            bg.drawLine (width-1, 0, width-1, height);
            bg.drawLine (20, height-1, width-20, height-1);
            bg.setColor (new Color (255, 255, 255));
            bg.drawLine (0, 0, width-1, 0);
            bg.drawLine (0, 0, 0, height);
            bg.drawImage (ul, 3, 3, this);
            bg.drawImage (ur, width-17, 3, this);
            if (label!=null) {
                FontMetrics fm = bg.getFontMetrics();
                bg.setColor (Color.black);
                bg.drawString (label, width/2-fm.stringWidth(label)/2, fm.getHeight());
            }
            Rectangle clip = g.getClipBounds();
            if(clip != null)
                g.setClip(clip);
            g.drawImage(buffer, 0, 0, this);
            g.dispose();
        }

        /**
         *  Returns the preferred size of this component.
         *  @return A Dimension object representing the preferred size of this component.
         *  @see java.awt.Component#getPreferredSize
         */
        public Dimension getPreferredSize() {
            Dimension d = c.getPreferredSize();
            return new Dimension(40+(int)d.getWidth(), 20);
        }
    }

    private class BottomPanel extends Panel {
        private transient Graphics bg;
        private transient Image buffer;
        private transient int bufferWidth; 
        private transient int bufferHeight;
        private Component c;
        private Image ll;
        private Image lr;

        public BottomPanel (Image ll, Image lr, Component c) {
            super ();
            this.ll = ll;
            this.lr = lr;
            this.c = c;
        }        

        /**
         *  Updates this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#update
         */
        public void update(Graphics g) {
            paint(g);
        }

        /**
         *  Paints this component.
         *  @param g the graphics context.
         *  @see java.awt.Component#paint
         */	
        public void paint(Graphics g) {
            int height = getSize().height;
            int width = getSize().width;
            if(buffer == null || width != bufferWidth || height != bufferHeight) {
                buffer = createImage(width, height);
                bg = buffer.getGraphics();
                bufferWidth = width;
                bufferHeight = height;
            }
            bg.setColor (new Color (192, 192, 192));
            bg.fillRect (0, 0, width, height);
            bg.setColor (new Color (128, 128, 128));
            bg.drawLine (width-1, 0, width-1, height);
            bg.drawLine (0, height-1, width-1, height-1);
            bg.setColor (new Color (255, 255, 255));
            bg.drawLine (20, 0, width-20, 0);
            bg.drawLine (0, 0, 0, height);
            bg.drawImage (ll, 3, 3, this);
            bg.drawImage (lr, width-17, 3, this);
            Rectangle clip = g.getClipBounds();
            if(clip != null)
                g.setClip(clip);
            g.drawImage(buffer, 0, 0, this);
            g.dispose();
        }

        /**
         *  Returns the preferred size of this component.
         *  @return A Dimension object representing the preferred size of this component.
         *  @see java.awt.Component#getPreferredSize
         */
        public Dimension getPreferredSize() {
            Dimension d = c.getPreferredSize();
            return new Dimension(40+(int)d.getWidth(), 20);
        }
    }
}